netapp_ontap.models.volume_analytics API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_analytics`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeAnalyticsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeAnalytics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `scan_progress GET`

    Percentage of files in the volume that the file system analytics initialization scan has processed. Only returned when the state is `initializing`.

    Example: 17

  `state GET POST PATCH`

    File system analytics state of the volume. If this value is "on", ONTAP collects extra file system analytics information for all directories on the volume. There will be a slight impact to I/O performance to collect this information. If this value is "off", file system analytics information is not collected and not available to be viewed. If this value is "initializing", that means file system analytics was recently turned on, and the initialization scan to gather information all all existing files and directories is currently running. If this value is 'unknown' that means there was an internal error when determining the file system analytics state for the volume.

    Valid choices:

    - unknown
    - initializing
    - off
    - on
  `supported GET`

    This field indicates whether or not file system analytics is supported on the volume. If file system analytics is not supported, the reason will be specified in the "analytics.unsupported_reason" field.

  `unsupported_reason GET POST PATCH`

    The unsupported_reason field of the volume_analytics.